# Generated by Django 3.2.12 on 2022-03-27 14:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('simpel_menus', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='menuitem',
            name='icon',
        ),
    ]
